﻿Imports System.Net
Imports Newtonsoft.Json
Imports Newtonsoft.Json.Linq

Public Class Form1
    Private Sub btnDownload_Click(sender As Object, e As EventArgs) Handles btnDownload.Click
        Download()
    End Sub

    Private Function Download()
        Dim str1 As String = TextBox2.Text.Replace(" ", "+")
        Dim url As String = "https://api.datamuse.com/words?ml=" + str1
        Dim jsonContent As String = DownloadJson(url)

        ' Deserialize the JSON string into a List of Tag objects
        Dim tags As List(Of Tag) = JsonConvert.DeserializeObject(Of List(Of Tag))(jsonContent)

        ' Populate the TreeView
        PopulateTreeView(tags)
    End Function

    Private Sub PopulateTreeView(tags As List(Of Tag))
        treeViewJson.Nodes.Clear()
        For Each Tag In tags
            ' Create a root node for each unique word
            Dim rootNode As TreeNode = treeViewJson.Nodes.Add(Tag.word)

            ' Create a node for the score
            rootNode.Nodes.Add("Score: " & Tag.score.ToString())

            ' Create nodes for the tags
            Dim tagsNode As TreeNode = rootNode.Nodes.Add("Tags:")
            For Each t In Tag.tags
                tagsNode.Nodes.Add(t)
            Next
        Next
    End Sub

    Private Function DownloadJson(url As String) As String
        Try
            Using client As New WebClient()
                ' Download the JSON file as a string
                Return client.DownloadString(url)
            End Using
        Catch ex As Exception
            ' Handle any errors that may have occurred
            ''MessageBox.Show("Error: " & ex.Message)
            Return String.Empty
        End Try
    End Function

    Private Sub LoadJsonIntoTreeView(jsonContent As String)
        ' Parse the JSON content
        Dim jsonArray As JArray = JArray.Parse(jsonContent)
        treeViewJson.Nodes.Clear()

        For Each item As JObject In jsonArray
            ' Create a root node for each JSON object
            Dim rootNode As New TreeNode(item("word").ToString())
            treeViewJson.Nodes.Add(rootNode)

            ' Add phonetic
            If item("phonetic") IsNot Nothing Then
                rootNode.Nodes.Add("Phonetic: " & item("phonetic").ToString())
            End If

            ' Add phonetics
            If item("phonetics") IsNot Nothing Then
                For Each phonetic As JObject In item("phonetics")
                    Dim phoneticNode As New TreeNode("Phonetics")
                    rootNode.Nodes.Add(phoneticNode)

                    If phonetic("text") IsNot Nothing Then
                        phoneticNode.Nodes.Add("Text: " & phonetic("text").ToString())
                    End If

                    ' Check if the "audio" key exists
                    If phonetic("audio") IsNot Nothing Then
                        phoneticNode.Nodes.Add("Audio: " & phonetic("audio").ToString())
                    End If

                    ' Check if the "sourceUrl" key exists before accessing it
                    If phonetic("sourceUrl") IsNot Nothing Then
                        phoneticNode.Nodes.Add("Source URL: " & phonetic("sourceUrl").ToString())
                    End If

                    ' Check if the "license" object is present and has the 'name' and 'url' properties
                    If phonetic("license") IsNot Nothing Then
                        Dim license As JObject = phonetic("license")
                        phoneticNode.Nodes.Add("License: " & license("name").ToString() & " (" & license("url").ToString() & ")")
                    End If
                Next
            End If

            ' Add meanings
            If item("meanings") IsNot Nothing Then
                For Each meaning As JObject In item("meanings")
                    Dim meaningNode As New TreeNode("Meaning: " & meaning("partOfSpeech").ToString())
                    rootNode.Nodes.Add(meaningNode)
                    If meaning("definitions") IsNot Nothing Then
                        For Each definition As JObject In meaning("definitions")
                            Dim definitionNode As New TreeNode("Definition: " & definition("definition").ToString())
                            meaningNode.Nodes.Add(definitionNode)
                        Next
                    End If
                Next
            End If

            ' Add licenses and sourceUrls
            If item("license") IsNot Nothing Then
                Dim license As JObject = item("license")
                rootNode.Nodes.Add("License: " & license("name").ToString() & " (" & license("url").ToString() & ")")
            End If

            If item("sourceUrls") IsNot Nothing Then
                For Each sourceUrl As String In item("sourceUrls")
                    rootNode.Nodes.Add("Source URL: " & sourceUrl)
                Next
            End If
        Next

        treeViewJson.ExpandAll()
        ' Scroll to the top of the TreeView
        If treeViewJson.Nodes.Count > 0 Then
            treeViewJson.SelectedNode = treeViewJson.Nodes(0) ' Select the first node
            treeViewJson.SelectedNode = Nothing ' Deselect to scroll to the top
        End If

    End Sub

    Private Sub Form1_Load(sender As Object, e As EventArgs) Handles Me.Load
        KeyPreview = True
    End Sub

    Private Sub Form1_KeyDown(sender As Object, e As KeyEventArgs) Handles Me.KeyDown
        If e.KeyCode = Keys.Enter Then
            Download()
        End If
    End Sub

    Public Class Tag
        Public Property word As String
        Public Property score As Long
        Public Property tags As List(Of String)
    End Class

End Class

